pub struct AElfClient { /* private fields */ }Expand description
Async HTTP client used by the facade crate and lower-level integrations.
Implementations
Sourceimpl AElfClient
impl AElfClient
Sourcepub fn new(config: ClientConfig) -> Result<Self, AElfError>
pub fn new(config: ClientConfig) -> Result<Self, AElfError>
Creates a client backed by the default HTTP provider.
Sourcepub fn with_provider<P>(provider: P) -> Result<Self, AElfError>where
P: Provider + 'static,
pub fn with_provider<P>(provider: P) -> Result<Self, AElfError>where
P: Provider + 'static,
Creates a client from a custom provider implementation.
Sourcepub fn block(&self) -> BlockService
pub fn block(&self) -> BlockService
Returns block-related API helpers.
Sourcepub fn chain(&self) -> ChainService
pub fn chain(&self) -> ChainService
Returns chain-related API helpers.
Sourcepub fn net(&self) -> NetService
pub fn net(&self) -> NetService
Returns network-related API helpers.
Sourcepub fn tx(&self) -> TransactionService
pub fn tx(&self) -> TransactionService
Returns transaction-related API helpers.
Sourcepub fn utils(&self) -> ClientUtilsService
pub fn utils(&self) -> ClientUtilsService
Returns local utility helpers for transaction and address workflows.
Sourcepub fn transaction_builder(&self) -> TransactionBuilder
pub fn transaction_builder(&self) -> TransactionBuilder
Creates a transaction builder bound to this client.